@@ -11,7 +11,7 @@ from typing import Any, Optional, Type, Union
 
 import dbt.flags as flags
 import yaml
-from dbt.adapters.factory import register_adapter
+from dbt.cli.option_types import Package
 from dbt.clients import yaml_helper  # type: ignore
 from dbt.config.profile import Profile, read_profile
 from dbt.config.project import PartialProject, Project
@@ -20,13 +20,14 @@ from dbt.config.runtime import RuntimeConfig
 from dbt.contracts.graph.manifest import Manifest
 from dbt.exceptions import DbtProjectError
 from dbt.graph.graph import Graph
-from dbt.parser.manifest import ManifestLoader, parse_manifest
+from dbt.parser.manifest import parse_manifest
 from dbt.task.base import BaseTask, ConfiguredTask
 from dbt.task.build import BuildTask
 from dbt.task.clean import CleanTask
 from dbt.task.compile import CompileTask
 from dbt.task.debug import DebugTask
 from dbt.task.deps import DepsTask
+from dbt.task.docs.generate import GenerateTask
 from dbt.task.freshness import FreshnessTask
 from dbt.task.list import ListTask
 from dbt.task.run import RunTask
@@ -39,15 +40,10 @@ from dbt.tracking import initialize_from_flags
 
 from airflow_dbt_python.utils.enums import FromStrEnum, LogFormat, Output
 from airflow_dbt_python.utils.version import (
-    DBT_INSTALLED_GTE_1_7,
-    DBT_INSTALLED_GTE_1_8,
+    DBT_INSTALLED_GTE_1_9,
+    DBT_INSTALLED_GTE_1_10_7,
 )
 
-if DBT_INSTALLED_GTE_1_8:
-    from dbt.task.docs.generate import GenerateTask
-else:
-    from dbt.task.generate import GenerateTask  # type: ignore[no-redef]
-
 
 def parse_yaml_args(args: Optional[Union[str, dict[str, Any]]]) -> dict[str, Any]:
     """Parse YAML arguments as dbt would.
@@ -102,9 +98,11 @@ class BaseConfig:
     log_level_file: str = "none"
     record_timing_info: Optional[str] = None
     debug: Optional[bool] = None
-    quiet: Optional[bool] = None
-    no_print: Optional[bool] = None
     printer_width: int = 80
+    quiet: Optional[bool] = None
+    no_quiet: Optional[bool] = dataclasses.field(default=None, repr=False)
+    print: Optional[bool] = None
+    no_print: Optional[bool] = dataclasses.field(default=None, repr=False)
 
     # Mutually exclusive attributes
     defer: Optional[bool] = None
@@ -139,34 +137,65 @@ class BaseConfig:
         default=None, repr=False
     )
 
-    # dbt >= 1.7
-    if DBT_INSTALLED_GTE_1_7:
-        from dbt.cli.option_types import Package
+    include_saved_query: Optional[bool] = None
+    no_include_saved_query: Optional[bool] = dataclasses.field(default=None, repr=False)
 
-        include_saved_query: Optional[bool] = None
-        no_include_saved_query: Optional[bool] = dataclasses.field(
-            default=None, repr=False
-        )
+    clean_project_files_only: Optional[bool] = None
+    no_clean_project_files_only: Optional[bool] = dataclasses.field(
+        default=None, repr=False
+    )
 
-        clean_project_files_only: Optional[bool] = None
-        no_clean_project_files_only: Optional[bool] = dataclasses.field(
-            default=None, repr=False
-        )
+    partial_parse_file_diff: Optional[bool] = None
+    no_partial_parse_file_diff: Optional[bool] = dataclasses.field(
+        default=None, repr=False
+    )
 
-        require_resource_names_without_spaces: bool = False
+    inject_ephemeral_ctes: Optional[bool] = None
+    no_inject_ephemeral_ctes: Optional[bool] = dataclasses.field(
+        default=None, repr=False
+    )
 
-        add_package: Optional[Package] = None
-        dry_run: bool = False
-        lock: bool = False
-        static: bool = False
-        upgrade: bool = False
+    empty: Optional[bool] = None
+    no_empty: Optional[bool] = dataclasses.field(default=None, repr=False)
 
-    if DBT_INSTALLED_GTE_1_8:
-        require_model_names_without_spaces: bool = False
-        source_freshness_run_project_hooks: bool = False
-        exclude_resource_types: list[str] = dataclasses.field(
-            default_factory=list, repr=False
-        )
+    show_resource_report: Optional[bool] = None
+    no_show_resource_report: Optional[bool] = dataclasses.field(
+        default=None, repr=False
+    )
+
+    favor_state: Optional[bool] = None
+    no_favor_state: Optional[bool] = dataclasses.field(default=None, repr=False)
+
+    export_saved_queries: Optional[bool] = None
+    no_export_saved_queries: Optional[bool] = dataclasses.field(
+        default=None, repr=False
+    )
+
+    add_package: Optional[Package] = None
+    dry_run: bool = False
+    lock: bool = False
+    static: bool = False
+    upgrade: bool = False
+
+    require_model_names_without_spaces: bool = False
+    exclude_resource_types: list[str] = dataclasses.field(
+        default_factory=list, repr=False
+    )
+
+    # legacy behaviors - https://github.com/dbt-labs/dbt-core/blob/main/docs/guides/behavior-change-flags.md
+    require_batched_execution_for_custom_microbatch_strategy: bool = False
+    require_event_names_in_deprecations: bool = False
+    require_explicit_package_overrides_for_builtin_materializations: bool = True
+    require_resource_names_without_spaces: bool = True
+    source_freshness_run_project_hooks: bool = True
+    skip_nodes_if_on_run_start_fails: bool = False
+    state_modified_compare_more_unrendered_values: bool = False
+    state_modified_compare_vars: bool = False
+    require_yaml_configuration_for_mf_time_spines: bool = False
+    require_nested_cumulative_type_params: bool = False
+    validate_macro_args: bool = False
+    require_all_warnings_handled_by_warn_error: bool = False
+    require_generic_test_arguments_property: bool = False
 
     def __post_init__(self):
         """Post initialization actions for a dbt configuration."""
@@ -184,6 +213,8 @@ class BaseConfig:
                 to non-None values.
         """
         mutually_exclusive_attrs = (
+            ("quiet", False),
+            ("print", True),
             ("defer", False),
             ("partial_parse", True),
             ("log_cache_events", False),
@@ -197,6 +228,12 @@ class BaseConfig:
             ("write_json", True),
             ("include_saved_query", None),
             ("clean_project_files_only", True),
+            ("partial_parse_file_diff", True),
+            ("inject_ephemeral_ctes", True),
+            ("empty", False),
+            ("show_resource_report", False),
+            ("favor_state", None),
+            ("export_saved_queries", None),
         )
 
         for attrs, default_value in mutually_exclusive_attrs:
@@ -288,8 +325,7 @@ class BaseConfig:
                     task._flattened_nodes.append(task.manifest.sources[uid])
                 else:
                     raise DbtException(
-                        f"Node selection returned {uid}, expected a node or a "
-                        f"source"
+                        f"Node selection returned {uid}, expected a node or a source"
                     )
             task.num_nodes = len(
                 [n for n in task._flattened_nodes if not n.is_ephemeral_model]
@@ -318,53 +354,53 @@ class BaseConfig:
         flags.set_from_args(self, {})  # type: ignore
         project, profile = self.create_dbt_project_and_profile(extra_targets)
 
-        self.cls.set_log_format()
+        if not DBT_INSTALLED_GTE_1_9:
+            self.cls.set_log_format()  # type: ignore[attr-defined]
+
         initialize_from_flags(self.send_anonymous_usage_stats, self.profiles_dir)
 
         local_flags = flags.get_flags()
 
         runtime_config = self.create_runtime_config(project, profile)
 
-        if DBT_INSTALLED_GTE_1_8:
-            if issubclass(self.dbt_task, ConfiguredTask) and runtime_config:
-                manifest = parse_manifest(
-                    runtime_config,
-                    write_perf_info=write_perf_info,
-                    write=False,
-                    write_json=False,
-                )
-                task: BaseTask = self.dbt_task(
-                    args=local_flags, config=runtime_config, manifest=manifest
-                )
-            elif issubclass(self.dbt_task, DepsTask):
-                task = self.dbt_task(args=local_flags, project=project)
-            elif issubclass(self.dbt_task, DebugTask):
-                task = self.dbt_task(args=local_flags)
-            elif issubclass(self.dbt_task, CleanTask):
-                task = self.dbt_task(args=local_flags, config=project)
-            else:
-                task = self.dbt_task(args=local_flags)
+        if (
+            issubclass(self.dbt_task, ConfiguredTask)
+            and runtime_config
+            and not DBT_INSTALLED_GTE_1_10_7
+        ):
+            manifest = parse_manifest(
+                runtime_config,
+                write_perf_info=write_perf_info,
+                write=False,
+                write_json=False,
+            )
+            task: BaseTask = self.dbt_task(
+                args=local_flags, config=runtime_config, manifest=manifest
+            )
+        elif (
+            issubclass(self.dbt_task, ConfiguredTask)
+            and runtime_config
+            and DBT_INSTALLED_GTE_1_10_7
+        ):
+            manifest = parse_manifest(
+                runtime_config,
+                write_perf_info=write_perf_info,
+                write=False,
+                write_json=False,
+                # TODO: Support for catalog integrations
+                active_integrations=[],  # type: ignore
+            )
+            task = self.dbt_task(
+                args=local_flags, config=runtime_config, manifest=manifest
+            )
+        elif issubclass(self.dbt_task, DepsTask):
+            task = self.dbt_task(args=local_flags, project=project)
+        elif issubclass(self.dbt_task, DebugTask):
+            task = self.dbt_task(args=local_flags)
+        elif issubclass(self.dbt_task, CleanTask):
+            task = self.dbt_task(args=local_flags, config=project)
         else:
-            if issubclass(self.dbt_task, ConfiguredTask) and runtime_config:
-                register_adapter(runtime_config)  # type: ignore[call-arg]
-                manifest = ManifestLoader.get_full_manifest(
-                    runtime_config, write_perf_info=write_perf_info
-                )
-                task = self.dbt_task(
-                    args=self,  # type: ignore[arg-type]
-                    config=runtime_config,
-                    manifest=manifest,
-                )
-            elif issubclass(self.dbt_task, DepsTask):
-                task = self.dbt_task(args=self, project=project)
-            elif issubclass(self.dbt_task, DebugTask):
-                task = self.dbt_task(args=self, config=runtime_config)  # type: ignore[arg-type,call-arg]
-            else:
-                task = self.dbt_task(  # type: ignore[call-arg]
-                    args=self,  # type: ignore[arg-type]
-                    config=runtime_config,
-                    project=project,
-                )
+            task = self.dbt_task(args=local_flags)
 
         if self.compiled_target is not None:
             # Only supported by subclasses of dbt's GraphRunnableTask.
@@ -473,11 +509,10 @@ class BaseConfig:
         Returns:
             A dbt profile for the task represented by this configuration.
         """
-        if DBT_INSTALLED_GTE_1_8:
-            from dbt_common.clients.system import get_env
-            from dbt_common.context import set_invocation_context
+        from dbt_common.clients.system import get_env
+        from dbt_common.context import set_invocation_context
 
-            set_invocation_context(get_env())
+        set_invocation_context(get_env())
 
         if self.profiles_dir is not None:
             raw_profiles = read_profile(self.profiles_dir)
@@ -485,10 +520,10 @@ class BaseConfig:
             raw_profiles = {}
 
         if extra_targets:
-            profile = raw_profiles.setdefault(self.profile_name, {})
-            outputs = profile.setdefault("outputs", {})
+            raw_profile = raw_profiles.setdefault(self.profile_name, {})
+            outputs = raw_profile.setdefault("outputs", {})
             outputs.setdefault("target", self.target)
-            profile["outputs"] = {**outputs, **extra_targets}
+            raw_profile["outputs"] = {**outputs, **extra_targets}
 
         profile = Profile.from_raw_profile_info(
             raw_profile=raw_profiles.get(
@@ -510,11 +545,13 @@ class SelectionConfig(BaseConfig):
 
     exclude: Optional[list[str]] = None
     select: Optional[list[str]] = None
-    selector_name: Optional[list[str]] = None
     selector: Optional[str] = None
     state: Optional[Union[Path, str]] = None
     defer_state: Optional[Union[Path, str]] = None
 
+    # Kept for compatibility with dbt versions < 1.5
+    selector_name: Optional[str] = None
+
     # Kept for compatibility with dbt versions < 0.21
     models: Optional[list[str]] = None
 
@@ -695,6 +732,7 @@ class TestTaskConfig(SelectionConfig):
     singular: Optional[bool] = None
     store_failures: Optional[bool] = None
     which: str = dataclasses.field(default="test", init=False)
+    resource_types: Optional[list[str]] = None
 
     def __post_init__(self):
         """Support for type casting arguments."""
